#
# spec file for package sesdev
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           sesdev
Version:        1.12.1+1619444076.g04475be
Release:        62.42
Summary:        CLI tool to deploy and manage SES clusters
License:        MIT
URL:            https://github.com/SUSE/sesdev
Source0:        %{name}-%{version}.tar.gz
Source1:        checkin.sh
Source2:        README-checkin.txt
NoSource:       1
NoSource:       2

BuildArch:      noarch

%if 0%{?suse_version}
BuildRequires:  python-rpm-macros
%else
BuildRequires:  python3-devel
%endif
BuildRequires:  fdupes
BuildRequires:  python3-setuptools

%if 0%{?suse_version}
Requires:       python3-Jinja2 >= 2.10.1
Requires:       python3-libvirt-python >= 5.1.0
Requires:       python3-PrettyTable
Requires:       python3-PyYAML >= 3.13
%endif
%if 0%{?el8} || 0%{?fedora}
Requires:       python3-jinja2 >= 2.10.1
Requires:       python3-libvirt >= 5.1.0
Requires:       python3-prettytable
Requires:       python3-pyyaml >= 3.13
%endif
Requires:       python3-click >= 6.7
Requires:       python3-pycryptodomex >= 3.4.6
Requires:       python3-setuptools
Requires:       vagrant > 2.2.2
Requires:       vagrant-libvirt
Requires:       sesdev-qa = %{version}-%{release}

%if 0%{?el8} || 0%{?fedora}
%{?python_disable_dependency_generator}
%endif

%description
sesdev is a CLI tool for developers to help with deploying SES clusters.
This tool uses vagrant and libvirt to create VMs and install Ceph using
DeepSea. The tool is highly customizable and allows to choose different
versions of Ceph and SES, as well as, different versions of the openSUSE
based OS.

%package qa
Summary:    Integration test script for validating Ceph deployments

%description qa
Integration test script for validating Ceph clusters deployed
by sesdev

%prep
%autosetup -p1
%if 0%{?fedora} && 0%{?fedora} < 30
sed -i -e 's/^\s*lv.qemu_use_session = false$//g' seslib/templates/Vagrantfile.j2
%endif

%build
%py3_build

%install
%py3_install
%fdupes %{buildroot}%{python3_sitelib}
install -m 0755 -d %{buildroot}/%{_datadir}/%{name}/qa
install -m 0755 -d %{buildroot}/%{_datadir}/%{name}/qa/common
install -m 0755 qa/health-ok.sh %{buildroot}/%{_datadir}/%{name}/qa/health-ok.sh
install -m 0644 qa/common/common.sh %{buildroot}/%{_datadir}/%{name}/qa/common/common.sh
install -m 0644 qa/common/helper.sh %{buildroot}/%{_datadir}/%{name}/qa/common/helper.sh
install -m 0644 qa/common/json.sh %{buildroot}/%{_datadir}/%{name}/qa/common/json.sh
install -m 0644 qa/common/rgw.sh %{buildroot}/%{_datadir}/%{name}/qa/common/rgw.sh
install -m 0644 qa/common/zypper.sh %{buildroot}/%{_datadir}/%{name}/qa/common/zypper.sh

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{python3_sitelib}/seslib*/
%{python3_sitelib}/sesdev*/
%{_bindir}/%{name}
%dir %{_datadir}/%{name}

%files qa
%{_datadir}/%{name}/qa

%changelog
* Mon Apr 26 2021 Nathan Cutler <ncutler@suse.com>
- Update to 1.12.1+1619444076.g04475be:
  + upstream 1.12.1 release (2021-04-26)
    + deployment: Remove redundant node network code (PR #592)
    + contrib/nukevolz.sh: primitive script to recover wasted disk space (PR #593)
    + zypper: remove python3-base if it's installed (PR #594)
    + templates: disallow global ID reclaim (PR #596)
* Sun Mar 21 2021 Nathan Cutler <ncutler@suse.com>
- Update to 1.12.0+1616368506.g9bba186:
  + upstream 1.12.0 release (2021-03-22)
  * provision: enable coredumps (PR #566)
  * sesdev: support custom repo URLs pointing to .repo file (PR #571)
  * cephadm: add 'period update' in radosgw deployment (PR #579)
  * tox: add support for Python 3.8 (PR #582)
  * sesdev.spec: fix missing qa/common/rgw.sh (PR #572)
  * contrib/upgrade-demo-ses6-to-ses7.sh: fix (PR #573)
  * zypper: be more careful when installing systemd-coredump (PR #577)
  * sesdev: replace fancy list comprehension with simpleton code (PR #581)
  * deployment: saner processing of --deepsea-repo, --deepsea-branch (PR #584)
  * zypper.j2: remove Python 2 even on SLE-12-SP3 (PR #585)
  * provision.sh: persist systemd journal in SES7 only (PR #569)
  * ceph-salt: no cephadm for nodes with no sesdev roles (PR #570)
  * constant.py: drop nfs from octopus default roles (PR #587)
  * nautilus_pre_stage_4.sh.j2: adapt to syntax change in Nautilus 14.2.17 (PR #589)
  * qa/common/json.sh: adapt to change in ceph status json format (PR #590)
* Thu Dec  3 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.11.0+1607012263.g73dea97:
  + upstream 1.11.0 release (2020-12-03)
  * Implement --rgw-ssl option for deploying RGWs with SSL enabled (PR #557)
  * zypper: add repos when needed (PR #558)
  * ses7: use product container image when --product given (PR #561)
  * Handle image_paths_product, image_paths_devel overrides in config.yaml (PR #564)
  * seslib/constant.py: add SES7 Update repo (PR #565)
* Fri Nov 13 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.10.0+1605283435.g8e610fb:
  + upstream 1.10.0 release (2020-11-13)
  * contrib/standalone.sh: add --fqdn test cases (PR #523)
  * Implement --no-apparmor option (PR #543)
  * Expose Ceph Dashboard on CaaSP SES deployment (PR #553)
  * doc/README.md: add common pitfall "Failed to intialize libnetcontrol" (PR #554)
  * spec: pin sesdev-qa version to sesdev version (PR #551)
  * constant,zypper: use download.nue.suse.com instead of download.suse.de (PR #552)
  * deployment_day_2.sh: create CephFS using documented procedure (PR #555)
* Fri Oct 23 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.9.1+1603459604.g8c9ed2c
  + upstream 1.9.1 release (2020-10-23)
  * sesdev --devel flag: let click deduct type (PR #550)
* Fri Oct 23 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.9.0+1603448566.gcb3362c
  + upstream 1.9.0 release (2020-10-23)
  * constant: add missing SLE-15-SP[12] Product repos (PR #530)
  * Implement "sesdev upgrade" subcommand (PR #531)
  * Implement "sesdev reboot DEP_ID NODE" command (PR #532)
  * contrib/upgrade-demo-ses6-to-ses7.sh: add upgrade demo script (PR #535)
  * provision.sh: add helper_scripts Jinja template (PR #540)
  * exceptions: have SesDevException return optional exit code (PR #538)
  * deployment: wait for rebooted node to complete boot sequence (PR #539)
  * sesdev: fix --filestore regression (PR #545)
  * cephadm/deployment_day_2.sh.j2: do not fail on defective --dry-run (PR #546)
  * setup.cfg: include seslib/templates/cephadm/ directory in packaging (PR #548)
  * templates/zypper: do not install supportutils-plugin-ses in SES{5,6,7} (PR #526)
  * deepsea/nautilus_pre_stage_0.sh: refrain from patching DeepSea (PR #547)
* Thu Oct  8 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.8.0+1602174240.g45df4dd
  + upstream 1.8.0 release (2020-10-08)
  * Add support for IPv6 (PR #56)
  * contrib/deepsea_drive_replace.sh: new test script (PR #306)
  * ceph_salt: deploy and smoke-test Prometheus (PR #418)
  * ceph-salt: deploy and smoke-test Grafana (PR #475)
  * ceph-salt: deploy and smoke-test alertmanager (PR #480)
  * ceph-salt: deploy and smoke-test node-exporter (PR #496)
  * Support official Vagrant boxes from Vagrant Cloud (PR #476)
  * new msgr2 secure options (PR #481)
  * Add ability to deploy Ceph on Ubuntu "Bionic Beaver" 18.04 (PR #486)
  * add label for ses deployment on caasp (PR #488)
  * Implement --no-provision option to deploy "bare" VMs (PR #490)
  * Implement "sesdev link" for linking two clusters (PR #498)
  * Implement "sesdev status" subcommand (PR #502)
  * Implement "sesdev show DEP_ID --nodes-with-role=ROLE" (PR #506)
  * Make "sesdev box list" and "sesdev box remove" accept globs (PR #517)
  * create: implement --fqdn option, specify FQDN when appropriate (PR #519, PR #522)
  * replace --deploy/--no-deploy option with --provision/--no-provision (PR #490)
  * caasp4: remove anti-affinity for mons for single node (PR #495)
  * Revert "ceph_salt_deployment: add 1-minute grace period" (PR #521)
  * ceph-salt: set some network-related config params explicitly (PR #482)
  * deployment: do not assert if starting an existing deployment (PR #493)
  * deployment: do not populate public_network with "0/24" (PR #512)
  * qa: wait for grafanas to show up before counting them (PR #514)
  * qa: wait longer for cluster to become healthy (PR #515)
  * Add makecheck-specific repos only in "sesdev create makecheck" (PR #520)
  * zypper: install rbd-nbd on all Leap 15.2/SLE-15-SP2 nodes (PR #484)
  * Update pacific repos (PR #489)
  * qa/nfs: do not attempt to mount NFS export on "pacific" (PR #492)
  * deployment: use "vagrant up --provision" to start cluster (PR #501)
  * cleanup: move cephadm Day 2 provisioner to its own subdirectory (PR #513)
  * tox: run pip with --use-feature=2020-resolver (PR #516)
* Sun Sep 13 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.7.0+1599999069.g8f2e732
  + upstream 1.7.0 release (2020-09-13)
  * ceph_salt_deployment: do "ceph orch apply --dry-run" (PR #406)
  * single node CaaSP cluster (PR #427)
  * If --ssd option is given, attempt to make first additional disk
    non-rotational (PR #448)
  * Implement "sesdev box remove --all" feature (PR #451)
  * qa: support openSUSE Tumbleweed (PR #457)
  * Drop ceph-salt '/system_update' config (PR #447)
  * replace-mgr-modules: refrain from introducing Python 2 (PR #431)
  * deepsea: add ganesha roles to policy.cfg (PR #437)
  * deepsea: properly recognize deprecated ganesha role (PR #442)
  * ceph_salt_deployment: prevent Vagrant 2.2.10+ from deleting master
    node (PR #452)
  * provision.sh: disable host checking when SSHing within the cluster
    (PR #455)
  * ceph_salt_deployment: explicitly create mds service (PR #458)
  * contrib/standalone.sh: adapt to create always returning 0 (PR #460)
  * deepsea_deployment: really stop before Stage 0 (PR #462)
  * ceph-salt: Fix ceph image path config (PR #465)
  * ceph_salt_deployment: always wait for OSDs to appear (PR #466)
  * ceph_salt_deployment: deploy MDSs according to documentation
    (PR #468)
  * ceph_salt_deployment: extend OSD deployment timeout (PR #432)
  * caasp: set num_disks in same way as for ceph deployments (PR #434)
  * vet_configuration: vet caasp4 roles more carefully (PR #435)
  * cephadm: allow preparation of cluster for manual deployment (PR #436)
  * caasp: update to caasp 4.5 (PR #438)
  * deployment: disks even when explicit storage role not given (PR #439)
  * cleanup: move code out of Deployment/_generate_nodes() (PR #441)
  * ceph-salt: enable user to control which nodes get "admin" role
    (PR #443)
  * cleanup: streamline unit testing and code linting (PR #444)
  * ceph_salt_deployment: tolerate additional bootstrap MONs/MGRs that
    we didn't ask for (PR #449)
  * ceph_salt_deployment: expose ceph-salt errors early (PR #456)
  * ceph-salt: bootstrap minion no longer required to have admin role
    (PR #461)
  * Split ceph_salt_deployment.sh into "Day 1" and "Day 2" scripts
    (PR #471)
* Tue Aug 11 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.6.1+1597147109.g204bf79
  + upstream 1.6.1 release (2020-08-11)
  * ceph_salt_deployment: implement "--stop-before-ceph-orch-apply" (PR #415)
  * settings: rename straggler version_os_repo_mappings (PR #419)
  * setup.cfg: fix "options.package_data" file list (PR #424)
    (fixes a packaging regression introduced in 1.6.0)
  * sesdev: non-create, non-box functions in alphabetical order (PR #414)
  * Unify naming of role-related constants (PR #416)
  * CaaSP: remove hard dependency on loadbalancer (PR #422)
* Sun Jul 26 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.6.0+1595760860.gc353ea1
  + upstream 1.6.0 release (2020-07-26)
  * sesdev: implement --dry-run for create commands (PR #384)
  * ceph_salt_deployment: use mgr/nfs CLI to deploy NFS Ganesha (PR #385)
  * 'sesdev replace-mgr-modules' should also replace 'bin/cephadm' (PR #387)
  * qa: enable dashboard branding test on {octopus,ses7} (PR #392)
  * zypper: remove rsync if it's installed in the Vagrant Box (PR #395)
  * ceph_salt_deployment: "ceph -s" when OSDs fail to come up (PR #409)
  * deployment: run supportconfig with 1-hour timeout (PR #410)
  * provision.sh: persist the journal (PR #411)
  * ses5: stop patching srv/salt/ceph/time/ntp/default.sls (PR #407)
  * split seslib/__init__.py into several smaller files (PR #377, #380)
  * provision.sh: add all repos before installing packages (PR #381)
  * Refactor seslib/templates/provision.sh (PR #383)
  * deployment/status: aggregate global parameters (PR #393)
  * Improve the "show" subcommand and deployment configuration listing (PR #399)
  * Change --repo-priority default from "True" to "False" (PR #400)
  * seslib: revamp custom_repo (PR #402)
  * seslib/deployment: try to destroy the whole cluster at once (PR #403)
  * log: print log messages to the screen under certain circumstances (PR #404)
  * Rename "version_os_repo_mapping" to "version_devel_repos" (PR #408)
  * ceph_salt_deployment.sh: extend OSD timeout (PR #413)
  * qa/common/rgw: fix curl try-wait (PR #379)
  * sesdev: use Luminous roles for SES5 (PR #382)
  * ceph_salt_deployment: fix off-by-one error in OSDs wait loop (PR #394)
  * sesdev: fix --non-interactive/--force handling (PR #395)
  * deployment: generate static networks on create only (PR #401)
* Fri Jul  3 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.5.0+1593783262.g6d822da:
  + upstream 1.5.0 release (2020-07-03)
  * cephadm iSCSI deployment (PR #300)
  * "--filestore" option to deploy OSDs with FileStore (PR #341)
  * "--devel/--product" option and add-repo subcommand (PR #351)
  * qa: superficial test for presence of dashboard branding (PR #374)
  * qa: add IGW to existing tests (PR #372)
  * provisioning: set fqdn through vagrant and leave /etc/hosts alone (PR #199)
  * no longer support nautilus deployment in Tumbleweed (PR #352)
  * ceph_salt_deployment.sh: reduce number of "ceph orch apply" calls (PR #363)
  * sesdev: raise exception if --roles combined with --single-node (PR #376)
  * cleanup: replace "grep | wc --lines" with "grep --count" (PR #375)
  * makecheck: reasonable defaults for Ceph repo/branch (PR #277)
  * provision.sh: set up SSH keys earlier (PR #361)
  * provision.sh: avoid endless while loop (PR #365)
  * sesdev: sanitize makecheck deployment IDs (PR #371)
  * doc: Update the example Deployment id in sesdev help (PR #378)
  * qa/systemctl_test: better error message when FSID omitted (PR #373)
  * qa/rgw: run curl command in try-wait loop to ping RGW (PR #370)
  * qa: do not wait for non-existent daemons to start (PR #368)
  * qa: get RGW port from /etc/ceph/ceph.conf (PR #353)
* Sat Jun 20 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.4.0+1592681394.g28f5853:
  + upstream 1.4.0 release (2020-06-20)
  * added "replace-mgr-modules" subcommand (PR #24)
  * added "replace-ceph-salt" subcommand (PR #331)
  * added NFS (Ganesha) server deployment in {octopus,ses7,pacific} (PR #337)
  * qa: added curl-based RGW smoke test (PR #344)
  * qa: added systemctl-based smoke test (PR #347)
  * removed "--use-deepsea" option for {ses7,octopus,pacific} (PR #334)
  * ceph_salt_deployment: fix use_salt=True deployment (PR #326)
  * sync_clocks.sh: put chronyc calls in try_wait (PR #328)
  * qa: tolerate +1 MGRs in number_of_nodes_actual_vs_expected_test (PR #332)
  * ceph_salt_deployment: deploy OSDs from YAML (ServiceSpec) file (PR #203)
  * makecheck: possibly prophylactically downgrade libncurses6 (PR #325)
  * explicit "admin" role no longer allowed (PR #330)
  * seslib: move boilerplate ssh options into a staticmethod (PR #333)
  * deployment IDs are now vetted for correctness (PR #335)
  * seslib: generate comma-separated lists of nodes with each role (PR #345)
  * If not provided explicitly via the "--domain" option, new deployments now
    default to ".test" instead of ".com" as the cluster TLD (PR #350)
* Mon May 25 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.3.0+1590413709.g4ad4e03:
  + upstream 1.3.0 release (2020-05-25)
  * octopus/ses7: added "--stop-before-ceph-orch-apply" function (PR #301)
  * Implement RGW deployment in octopus, ses7 (PR #314)
  * ceph_salt_deployment: do not force user to change dashboard pw (PR #315)
  * makecheck: possibly prophylactically downgrade libudev1 (PR #317)
  * contrib/standalone.sh: --no-stop-on-failure option (PR #318)
  * ceph_salt_deployment: make use of 'cephadm' role (PR #319)
  * octopus/ses7: removed "--deploy-mons", "--deploy-mgrs", "--deploy-osds",
    "--deploy-mdss" (replaced by "--stop-before-ceph-orch-apply") (PR #301)
  * seslib: drop Containers module from SES7 deployment (PR #303)
  * provision.sh: remove curl RPM from the environment (PR #311)
  * Fixed "sesdev create caasp4" default deployment by disabling multi-master (PR #302)
  * ceph_salt_deployment: do not deploy MDS if no mds roles present (PR #313)
  * caasp: do not install salt (PR #320)
  * supportconfig: handle both scc and nts tarball prefixes (PR
  * seslib: convert certain public methods into private (PR #309)
  * caasp4: rename "storage" role to "nfs" and drop it from default 4-node
    deployment (PR #310)
* Mon May  4 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.2.0+1588616857.gaa3df4c:
  + upstream 1.2.0 release (2020-05-04)
  * deepsea_deployment: pre-create Stage 4 pools (PR #298)
  * setup.cfg: do not break Tumbleweed RPM install (PR #297)
  * ceph_salt_deployment.sh: rip out time sync code (PR #289)
  * Rename '--stop-before-ceph-salt-deploy' to '--stop-before-ceph-salt-apply'
    (PR #290)
* Tue Apr 28 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.12+1588084576.g8b2afa1:
  + upstream 1.1.12 release (2020-04-28)
  * provision.sh: enable autorefresh on all repos (PR #288)
  * seslib: fix "Unused argument" linter warning (PR #286)
  * provision.sh.j2: Properly prepare CaaSP nodes (PR #283)
  * ceph_salt_deployment: really sync clocks (PR #285)
  * Rename 'ceph-salt deploy' to 'ceph-salt apply' (PR #280)
* Fri Apr 24 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.11+1587722868.gc7e5625:
  + upstream 1.1.11 release (2020-04-24)
  * Implement feature "sesdev create makecheck" (PR #236)
  * Deployment: silently add "master" and "bootstrap" roles (PR #254)
  * sesdev: implement "sesdev list --format json" and PrettyTable-based
    "sesdev list" (PR #259)
  * qa: fix maybe_wait_for_mdss test (PR #262)
  * provision.sh: remove Non-OSS repos on openSUSE (PR #265)
  * sesdev: support Click 6.7 (PR #268)
  * seslib: more robust dashboard tunnelling (PR #274)
  * deepsea: "openattic" role needs Stage 4 (PR #275)
  * provision.sh: refactor while loops and fix packaging-related breakage
    (PR #279)
  * Remove "disable cephadm bootstrap" functionality (PR #261)
  * Rename --deepsea-cli and --ceph-salt-deploy options to --salt
    (PR #267)
* Fri Apr 17 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.10+1587124098.ga2f8189:
  + upstream 1.1.10 release (2020-04-17)
  * ceph_salt_deployment: sync clocks after deployment (PR #187)
  * ceph_salt_deployment: fetch GitHub PRs when needed (PR #197)
  * New deployment type "pacific" using packages/containers built from
    upstream Ceph "master" branch (PR #200)
  * README.md: Needed packages for all major distros (PR #209)
  * sesdev: systemically vet roles on create (PR #215)
  * templates: extend --qa-test to DeepSea-deployed versions (PR #230)
  * sesdev: make deployment_id argument optional (PR#235)
  * sesdev: Globbing for "stop", "start", and "destroy" (PR #238)
  * new --synced-folder option to NFS mount directories (PR #247)
  * ses7, octopus, pacific: Deploy MDSs (PR #258)
  * deepsea_deployment: run Stage 4 only if justified by roles (PR #205)
  * seslib: install sesdev-generated keypair under non-default name (PR #207)
  * Jenkinsfile.integration: Retry jenkins slave deletion (PR #214)
  * ceph_salt_deployment: use --prefix /usr with "pip install" (PR #221)
  * deepsea_deployment: check if drive_groups.yml exists (PR #229)
  * seslib: force ses5 prometheus node to master (PR #232)
  * provision.sh: reinstall certain packages from the update repos (PR #243)
  * ceph_salt_deployment: do not provision client-only nodes (PR #246)
  * ceph_salt_deployment: move OSD deployment to sesdev (PR #186)
  * ceph_salt_deployment: use sesdev to deploy MONs and MGRs (PR #189)
  * sesdev: uniform --force/--non-interactive (PR #201)
  * ceph_salt_deployment: make it easier to install ceph-salt from source (PR #210)
  * seslib: make all str-type settings default to the empty string (PR #217)
  * ceph_salt_deployment: Use quoted string to set bootstrap configs (PR #224)
  * ceph_salt_deployment: use lower-case on config nodes (PR #226)
  * ceph_salt_deployment: do not refresh/sync pillar data (PR #227)
  * templates: move test.ping try-wait into a separate file (PR #234)
* Thu Mar 26 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.9+1585227448.g3a7e36e:
  + upstream 1.1.9 release (2020-03-26)
  * config.yaml: enable setting of repo priority in version_os_repo_mapping (PR #163)
  * provision.sh: add SUSE:CA repo on ses5 (PR #166)
  * Implement feature: "sesdev ssh DEP_ID NODE_ID COMMAND" (PR #175)
  * Implement feature: "sesdev supportconfig DEPLOYMENT_ID NODE_ID" (PR #176)
  * Implement feature: --encrypted-osds (PR #192)
  * provision.sh: do not fail ses5 deployment if ntp not installed (PR #173)
  * ceph_salt_deployment.sh: adapt Drive Group string to new syntax (PR #178)
  * qa/health-ok.sh: wait for OSD nodes to show up (PR #180)
  * Vagrantfile,sesdev.spec: require vagrant > 2.2.2 (PR #167)
  * Use "filesystems:ceph:octopus:upstream" for default cephadm/container build (PR #170)
  * Set "osd crush chooseleaf type = 0" via bootstrap ceph.conf in very small clusters (PR #183)
  * ceph_salt_deployment.sh: Fetch github PRs when installing from src (PR #190)
* Fri Mar 13 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.8+1584097308.ga30c06e:
  + upstream 1.1.8 release (2020-03-13)
  * seslib: remove host's virtual networks on destroy (PR #102)
  * Jenkinsfile.integration for PR testing (PR #118, PR #154)
  * prometheus and alertmanager tunnels (PR #148)
  * tests: enable unit testing via tox (PR #151)
  * seslib: stop printing misleading device names (PR #150)
  * seslib: Set admin roles for octopus (PR #158)
  * Change "admin" role semantics and make roles configurable (PR #161)
  * Allow user to override parts of OS_REPOS, VERSION_OS_REPO_MAPPING, and
    IMAGE_PATHS (PR #146)
* Mon Mar  9 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.7+1583767117.gc963107:
  + upstream 1.1.7 release (2020-03-09)
  * all PRs mentioned in this changelog since 1.1.6, plus
  * spec: always install sesdev-qa RPM along with sesdev (PR #144)
* Mon Mar  9 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.6+1583755459.gda48565:
  + spec: disable RH/Fedora Python dependendency generator (PR #140)
  + ceph_salt_deployment: honor --no-deploy-osds option (PR #143)
  + Let --debug run "vagrant up/destroy" in debug mode (PR #89)
* Fri Mar  6 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.6+1583488232.gfdcc651:
  + qa: fix path to qa scripts for RPM case (PR #141)
  + ceph_salt_deployment: run "ceph-salt status" after "ceph-salt config ls"
    (PR #138)
* Thu Mar  5 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.6+1583428626.ga138314:
  + upstream 1.1.6 release (2020-03-05)
  * sesdev: add --non-interactive option to "sesdev create" (PR #125)
  * Implement "sesdev qa-test" command (PR #129)
  * qa: assert "ceph versions" matches "ceph --version" (PR #131)
  * seslib: correct downstream container for "sesdev create {ses7,octopus}" (PR #130)
  * provision.sh: remove Python 2 so it doesn't pollute the environment (PR #133)
  * Rename --ceph-container-image to --image-path (PR #115)
  * provision: install "command-not-found", "supportutils", etc. in test environments (PR #123)
  * Return with a non-zero exit code in a failure case (PR #127)
  * seslib: rename --deploy-bootstrap to --cephadm-bootstrap (PR #137)
* Wed Feb 26 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.5+1582717868.g68df753:
  + upstream 1.1.5 release (2020-02-26)
  * sesdev.spec: use standard ordering of sections
  * sesdev: give the user a way to specify --no-deploy-... (PR #120)
  * seslib: fix --no-deploy-mgrs option not working (PR #122)
* Wed Feb 26 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.4+1582707984.gdb87191
  + upstream 1.1.4 release (2020-02-26)
  * sesdev.spec: properly package /usr/share/sesdev directory
    (follow-on fix for PR #112)
* Tue Feb 25 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.3+1582639489.g0e91afa:
  + upstream 1.1.3 release (2020-02-25)
  * Rename ceph-bootstrap to ceph-salt (PR#114)
  * Migrate ceph-bootstrap-qa to sesdev (part 2) (PR#112)
  * provision: remove which RPM from test environment (PR#113)
  * ceph_salt_deployment: disable system update and reboot (PR#117)
  * seslib: by default, a mgr for every mon (PR#111)
* Mon Feb 17 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.2+1581962442.g190d64e:
  + upstream 1.1.2 release (2020-02-17)
  * Implement "vagrant box list" and "vagrant box remove" (PR#69)
  * Allow user to specify custom private key file for remote libvirt (PR#71)
  * spec: add Fedora-specific Requires (PR#77)
  * Pillar is now automatically configured by ceph-bootstrap (PR#78)
  * Implement "sesdev scp" feature (PR#101)
  * Implement "sesdev create caasp4" feature (PR#103)
  * Miscellaneous spec file cleanups and bugfixes (PR#72)
  * several fixes for octopus/ses7 deployment (PR#76)
  * Remove any orphaned images after destroy (PR#81)
  * seslib: fix Ceph repos for ses5, ses6, ses7 (PR#83)
  * tools/run_async: decode stderr bytes (PR#88)
  * libvirt/network: autostart networks per default (PR#93)
  * Fix NTP issue that was causing SES5 deployment to fail (PR#108)
  * Increase chances of getting the latest ses7 packages (PR#84)
  * ceph_bootstrap_deployment: log cephadm and ceph-bootstrap version (PR#86)
  * ceph_bootstrap: restart salt-master after ceph-bootstrap installation (PR#87)
  * seslib: add SES7 Internal Media when --qa-test given (PR#90)
* Sat Feb  1 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.1+1580550501.gd6782ab:
  + changes from upstream SHA1 d6782abc3002a5a8ec299b1897ad6166a786bafa:
  * Revamp --num-disks handling (PR #65)
  * doc: globally change 'rjfd' to 'SUSE' (PR #66)
  * ceph_bootstrap_deployment: "ceph-bootstrap -ldebug deploy" (PR #68)
  * checkin.sh: use NoSource
  * spec:
    = drop Group
    = streamline %%autosetup
    = fix Fedora conditional
* Wed Jan 29 2020 Nathan Cutler <ncutler@suse.com>
- Update to 1.1.1+1580302614.g0e79816:
  + upstream 1.1.1 release (2020-01-29)
  * Octopus and SES7 deployment with ceph-bootstrap (PR #28)
  * Implement --repo-priority / --no-repo-priority (PR #19)
  * Add option for predefined libvirt networks (PR #39)
  * qa: initial qa integration (PR #46)
  * When deploying ses5 with explicit --roles, do not add openattic (PR #23)
  * Enable display of manpages (PR #33)
  * ceph_bootstrap_deployment.sh: Also set -e (PR #35)
  * vagrant: generate random serial number for each attached disk (PR #50)
  * ceph_bootstrap_deployment: ensure minions are responding (PR #52)
  * Add node info to SSH tunnel command (PR #27)
  * Display amount of deployed VMs in status output (PR #31)
  * Enable linter via travis (PR #38)
  * ceph-bootstrap: 'ceph-salt-formula' moved to 'ceph-bootstrap' (PR #44)
  * ceph_bootstrap: use "ceph-bootstrap deploy" command to run ceph-salt formula (PR #62)
* Wed Nov 27 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 1.1.0+1574848386.g395e92f:
  + Add Github Action to publish to OBS (PR #10).
  + SUMA deployment in `octopus` version (PR #14).
  + Handle Ctrl+C on deployment creation (PR #8).
  + seslib: fixed 100%% cpu usage when deploying cluster (PR #16).
  + Updated README.md on how to use an editable Python venv (PR #15).
  + cli: `list` subcommand now shows the version of each deployment (PR #12).
  + octopus and ses7 versions now use the OBS repo
    filesystems:ceph:master:upstream that is updated in a daily basis (PR #13).
* Fri Nov 15 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 1.0.3+1573815567.g0a8bfe0:
  + README instructions about libvirt configuration.
  + CLI subcommand `info` replaced by `show`.
  + fix typo in `sesdev start --help` command.
* Fri Nov 15 2019 Ricardo Dias <ricardo.dias@suse.com>
-Update to 1.0.2+1573810156.g0c0dc21:
  + fix missing libvirt engine jinja template in setup.py.
* Thu Nov 14 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 1.0.1+1573758931.gfcc2a87:
  + fix missing jinja templates in setup.py
* Thu Nov 14 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 1.0.0+1573749027.g0e3c988
  + This version adds:
  * `--libvirt-(user|storage-pool)` options to CLI.
  * `--stop-before-deepsea-stage` option to CLI.
  * `--cpus` option to CLI.
  * `--ram` option to CLI.
  * `--disk-size` option to CLI.
  * `--repo` option to CLI.
  * `--vagrant-box` option to CLI.
  * openSUSE Leap 15.2 distro.
  * SLES-15-SP2 distro.
  * SES7 deployment based on SLES-15-SP2 (no Ceph cluster deployment yet).
  * SES5 deployment based on SLES-12-SP3.
  * SES6 deployment based on SLES-15-SP1.
  * Octopus deployment based on Leap 15.2 (DeepSea is working 90%%).
  * Installation instructions to the README.md.
  * openATTIC service tunneling support.
  * Deployment description with `sesdev info <deployment_id>`.
  + This version changes:
  * Use `libvirt_use_ssh` instead of `libvirt_use_ssl` to configure SSH
    access.
  * Vagrantfile template refactoring to support different deployment tools.
  * Currently only DeepSea is implemented.
  * Code refactoring to support other VM engines besides libvirt.
  * CLI creation command changed to include the SES version we want to
    deploy. Now the command looks like:
    `sesdev create <version> [options] <deployment_id>`.
  * List deployments now return the status and the name of the nodes in each
    deployment.
  + This version fixes:
  * remove `qemu_use_session` vagrant-libvirt setting when packaging for
    Fedora 29.
  * Use `RSA#exportKey` method to work with version 3.4.6 of pycrytodomex.
  * Fixed type of `stop-before-stage` setting.
  * Fix ssh command when libvirt is located in the localhost.
  * Fix accepting salt-keys step in deployment by polling `salt-key -L`.
  * Fix deployment status when `vagrant up` was never run.
  * Only create deployment directory and files after rendering Vagranfile
    without errors.
* Thu Oct 31 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.2+1572514937.g763077e:
  + seslib: remove proxycmd defined check
* Wed Oct 30 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.2+1572456477.g821bf75:
  + added `--stop-before-deepsea-stage` option to CLI
  + Fixed type of `stop-before-stage` setting
  + Fix ssh command when libvirt is located in the localhost
  + Fix accepting salt-keys step in deployment by polling salt-key -L
* Wed Oct 30 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.2+1572448838.g949e537:
  + Use `RSA#exportKey` method to work with version 3.4.6 of pycrytodomex.
* Wed Oct 30 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.2+1572442776.g5642890:
  + added `--libvirt-(user|storage-pool)` options to CLI.
  + remove `qemu_use_session` vagrant-libvirt setting when packaging for
    Fedora 29.
* Wed Oct 30 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.2+1572398417.g8502032:
  + explicitly set `qemu_use_session = false` in Vagrantfile to always use a
    system connection.
  + openSUSE requires python3-setuptools to run sesdev.
* Wed Oct 30 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.1+1572395804.g50771b7:
  + replaced `pycryptodome` library by `pycryptodomex`
  + fixed library dependencies
* Tue Oct 29 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.1+1572393386.g30bf7ee:
  + add buildrequires python-rpm-macros for fedora in spec file
* Tue Oct 29 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.1+1572392665.gd519454:
  + add buildrequires python3-rpm-macros for fedora in spec file
* Tue Oct 29 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.1+1572390481.g4783094:
  + added buildrequires fdupes to spec file
* Tue Oct 29 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.1+1572389564.g053fa8c:
  + fix Fedora dependencies naming
* Tue Oct 29 2019 Ricardo Dias <ricardo.dias@suse.com>
- Update to 0.2.1+1572388507.g1a6c855:
  + fix Fedora python rpm build macros in the specfile
* Tue Oct 29 2019 Ricardo Dias <rdias@suse.com>
- Initial commit, based on rjfd/sesdev.git branch "master",
  SHA1 5ca48bdfcef62cfa552947c31007a6cb6ba5963a
